NormalParam

Struct NormalParam 

pub struct NormalParam {
    pub normal: Normal,
    pub default: Normal,
    pub unmodulated_normal: Option<Normal>,
}
A paramater that contains a normalized value and a default_value.

The values are stored as the Normal type.

Fields

normal: Normal

The value of the parameter represented as a Normal

default: Normal

The default value of the parameter represented as a Normal

unmodulated_normal: Option<Normal>

An optional value of the parameter represented as a Normal before any modulation from the host is applied. This may be useful for displaying modulation differently in plugin GUIs. Right now only CLAP plugins in Bitwig Studio is known to use this feature.

Implementations

Source

impl NormalParam

pub fn new(normal: impl Into<Normal>, default: impl Into<Normal>) -> Self

pub fn set(&mut self, normal: impl Into<Normal>)

Updates the Normal value of this NormalParam

pub fn from_nice(param: &impl Param) -> Self