HSlider

Struct HSlider 

pub struct HSlider<'a, Message, Theme: StyleSheet> { /* private fields */ }
A horizontal slider GUI widget that controls a NormalParam

an HSlider will try to fill the horizontal space of its container.

Implementations

Source

impl<'a, Message, Theme> HSlider<'a, Message, Theme>
where Theme: StyleSheet,

pub fn new(normal_param: impl Into<NormalParam>) -> Self
where <Theme as StyleSheet>::Style: Default,

Creates a new HSlider.

  • normal_param - The normalized value of the parameter.
pub fn on_gesture(self, on_gesture: impl 'a + FnMut(Gesture) -> Message) -> Self

Sets the message to emit when the user gestures this widget.

pub fn config(self, config: &Config) -> Self

Set a custom configuration to use for this virtual slider.

pub fn drag_horizontally(self, drag_horizontally: bool) -> Self

Set whether this slider is dragged horizontally (true) or vertically (false).

The default value is true.

pub const fn enabled(self, enabled: bool) -> Self

Enable/disable this widget.

The default is true.

pub fn width(self, width: Length) -> Self

Sets the width of the HSlider.

The default height is Length::Fill.

pub fn height(self, height: Length) -> Self

Sets the height of the HSlider.

The default height is Length::Fixed(14).

pub fn style(self, style: impl Into<<Theme as StyleSheet>::Style>) -> Self

Sets the style of the HSlider.

pub fn tick_marks(self, tick_marks: &'a Group) -> Self

Sets the tick marks to display. Note your StyleSheet must also implement tick_marks_style(&self) -> Option<tick_marks::Style> for them to display (which the default style does).

pub fn text_marks(self, text_marks: &'a Group) -> Self

Sets the text marks to display. Note your StyleSheet must also implement text_marks_style(&self) -> Option<text_marks::Style> for them to display (which the default style does).

pub fn mod_range(self, mod_range: Option<&'a ModulationRange>) -> Self

Sets a ModulationRange to display. Note your StyleSheet must also implement mod_range_style(&self) -> Option<ModRangeStyle> for them to display.

pub fn mod_range_2(self, mod_range: Option<&'a ModulationRange>) -> Self

Sets a second ModulationRange to display. Note your StyleSheet must also implement mod_range_style_2(&self) -> Option<ModRangeStyle> for them to display.