pub struct NormalParam {
pub normal: Normal,
pub default: Normal,
pub unmodulated_normal: Option<Normal>,
}Expand description
A paramater that contains a normalized value and a default_value.
The values are stored as the Normal type.
Fields
normal: NormalThe value of the parameter represented as a Normal
default: NormalThe default value of the parameter represented as a Normal
unmodulated_normal: Option<Normal>An optional value of the parameter represented as a Normal before any
modulation from the host is applied. This may be useful for displaying
modulation differently in plugin GUIs. Right now only CLAP plugins in
Bitwig Studio is known to use this feature.
Implementations